==> odoo14_addon_l10n_br_fiscal-14.0.10.3.1-py3-none-any.whl: odoo/addons/l10n_br_fiscal/models/__init__.py <==
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from . import data_abstract
from . import data_product_abstract
from . import data_ncm_nbs_abstract
from . import document_workflow
from . import document_fiscal_mixin_methods
from . import document_fiscal_mixin
from . import document_fiscal_invoice_mixin
from . import document_fiscal_line_mixin_methods
from . import document_fiscal_line_mixin
from . import document_event
from . import document_eletronic
from . import invalidate_number
from . import comment
from . import ibpt
from . import cfop
from . import cst
from . import cnae
from . import nbs
from . import service_type
from . import ncm
from . import nbm
from . import ncm_nbm
from . import cest
from . import ncm_cest
from . import tax_group
from . import tax
from . import tax_pis_cofins
from . import tax_pis_cofins_base
from . import tax_pis_cofins_credit
from . import ncm_tax_pis_cofins
from . import tax_ipi_control_seal
from . import tax_ipi_guideline
from . import tax_ipi_guideline_class
from . import tax_estimate
from . import tax_definition
from . import tax_definition_company
from . import tax_definition_cfop
from . import tax_definition_icms
from . import tax_definition_operation_line
from . import tax_definition_partner_profile
from . import icms_regulation
from . import icms_relief
from . import document_type
from . import document_serie
from . import product_genre
from . import certificate
from . import product_mixin
from . import product_template
from . import product_product
from . import simplified_tax
from . import simplified_tax_range
from . import operation
from . import operation_line
from . import operation_document_type
from . import partner_profile
from . import res_partner
from . import res_company
from . import document
from . import document_related
from . import document_line
from . import res_config_settings
from . import res_country_state
from . import uom_uom
from . import uom_uom_alternative
from . import operation_dashboard
from . import subsequent_operation
from . import subsequent_document
from . import document_email
from . import city_taxation_code

from . import dfe
from . import mdfe

==> odoo14_addon_l10n_br_fiscal-14.0.14.1.1-py3-none-any.whl: odoo/addons/l10n_br_fiscal/models/__init__.py <==
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from . import data_abstract
from . import data_product_abstract
from . import data_ncm_nbs_abstract
from . import document_workflow
from . import document_fiscal_mixin_methods
from . import document_fiscal_mixin
from . import document_move_mixin
from . import document_fiscal_line_mixin_methods
from . import document_fiscal_line_mixin
from . import document_event
from . import document_eletronic
from . import invalidate_number
from . import comment
from . import ibpt
from . import cfop
from . import cst
from . import cnae
from . import nbs
from . import service_type
from . import ncm
from . import nbm
from . import ncm_nbm
from . import cest
from . import ncm_cest
from . import tax_group
from . import tax
from . import tax_pis_cofins
from . import tax_pis_cofins_base
from . import tax_pis_cofins_credit
from . import ncm_tax_pis_cofins
from . import tax_ipi_control_seal
from . import tax_ipi_guideline
from . import tax_ipi_guideline_class
from . import tax_estimate
from . import tax_definition
from . import tax_definition_company
from . import tax_definition_cfop
from . import tax_definition_icms
from . import tax_definition_operation_line
from . import tax_definition_partner_profile
from . import icms_regulation
from . import icms_relief
from . import document_type
from . import document_serie
from . import product_genre
from . import certificate
from . import product_mixin
from . import product_template
from . import product_product
from . import simplified_tax
from . import simplified_tax_range
from . import operation
from . import operation_line
from . import operation_document_type
from . import partner_profile
from . import res_partner
from . import res_company
from . import document
from . import document_related
from . import document_line
from . import res_config_settings
from . import res_country_state
from . import uom_uom
from . import uom_uom_alternative
from . import operation_dashboard
from . import subsequent_operation
from . import subsequent_document
from . import document_email
from . import city_taxation_code

from . import dfe
from . import mdfe
